@@ -201,4 +201,21 @@ def cal_performance(save_path, start_date, end_date):
 
     result_dict['return_to_bah'] = return_on_capital / bah_return
 
+    # Singal Win Rate By Year
+    for current_year in year_list:
+        df_year = df.copy()
+        df_year['year'] = pd.DatetimeIndex(df_year['date']).year
+        df_year = df_year.loc[df_year['year'] == current_year]
+
+        signal_by_year = df_year['action'].value_counts()
+        df_year = df_year[df_year['action'].notnull()].reset_index(drop=True)
+
+        num_of_trade = signal_by_year['open'] if 'open' in signal_by_year else 0
+        num_of_loss = len(df_year[df_year['realized_pnl'] < 0])
+        num_of_win = num_of_trade - num_of_loss
+
+        win_rate = str(int(round(100 * num_of_win / num_of_trade, 0))) if num_of_trade > 0 else '--'
+
+        result_dict[f'{current_year}_win_rate'] = win_rate
+
     return result_dict
\ No newline at end of file
