@@ -7,7 +7,7 @@ from dash import dcc, html    ## pip install dash
 import dash_bootstrap_components as dbc
 import plotly.express as px
 import plotly.graph_objs as go
-
+from plotly.subplots import make_subplots
 
 
 class Components:
@@ -16,19 +16,12 @@ class Components:
     sort_method_dropdown = html.Div(
         dbc.Select(id='sort_method',
                    placeholder="Select Sorting Method",
-                   # value='Top 20 Net Profit',
+                   value='Top 20 Net Profit',
                    options=[{'label': 'Top 20 Net Profit', 'value': 'Top 20 Net Profit'},
                             {'label': 'Top 20 Net Profit to MDD', 'value': 'Top 20 Net Profit to MDD'}, ],
-                   style={'border-radius': '5px', 'font-size': '12px', }),
-        style={'padding-left': '12.5px', 'width': '280px'})
+                   style={'border-radius': '5px',   'font-size': '12px', }),
+        style={'padding-left': '12.5px', 'width': '240px'})
 
-    subchart_dropdown = html.Div(
-        dbc.Select(id='subchart_dropdown',
-                   placeholder="Select Sorting Method",
-                   options=[{'label': 'Top 20 Net Profit', 'value': 'Top 20 Net Profit'},
-                            {'label': 'Top 20 Net Profit to MDD', 'value': 'Top 20 Net Profit to MDD'}, ],
-                   style={'border-radius': '5px', 'font-size': '12px', }),
-        style={'padding-left': '12.5px', 'width': '230px'})
 
     filter_dropdown = html.Div(id='filter_dropdown',
                                children=dbc.Select(id='filter_name',
@@ -49,14 +42,14 @@ class Components:
                                                        {'label': 'Win Rate <', 'value': 'win_rate<'},
                                                    ],
                                                    style={'border-radius': '5px', 'font-size': '12px'}),
-                               style={'padding-left': '15px', 'width': '210px'})
+                               style={'padding-left': '15px', 'width': '180px'})
 
     filter_dropdown_disabled = html.Div(id='filter_dropdown',
                                         children=dbc.Select(id='filter_name', disabled=True,
                                                             placeholder="Select Filter",
                                                             style={'border-radius': '5px', 'font-size': '12px',
                                                                    'backgroundColor': 'Gray'}),
-                                        style={'padding-left': '15px', 'width': '210px'})
+                                        style={'padding-left': '15px', 'width': '180px'})
 
     filter_input = dbc.Input(id='filter_input', value=None, size="md", type='text',
                              style={'width': '50px', 'margin-right': '5px', 'border-radius': '3px',
@@ -66,18 +59,20 @@ class Components:
                                       style={'width': '50px', 'margin-right': '5px', 'border-radius': '3px',
                                                'padding': '6px 5px', 'font-size': '12px', 'backgroundColor': 'Gray'})
 
-    add_button_style = {'margin-left': '50px', 'width': '180px', 'backgroundColor': 'blue',
-                        'border-radius': '5px', 'text-align': 'center', 'cursor': 'pointer'}
+    add_button_style = {'margin-left': '50px', 'width': '150px', 'backgroundColor': 'blue',
+                        'border-radius': '5px', 'text-align': 'center', 'cursor': 'pointer',
+                        'font-size': '13px', 'height':'30px'}
 
-    add_button_style_disabled = {'margin-left': '50px', 'width': '180px', 'color': 'Silver', 'backgroundColor': 'Gray',
-                                 'border-radius': '5px', 'text-align': 'center'}
+    add_button_style_disabled = {'margin-left': '50px', 'width': '150px', 'color': 'Silver', 'backgroundColor': 'Gray',
+                                 'border-radius': '5px', 'text-align': 'center',
+                                 'font-size': '13px', 'height':'30px'}
 
 
     def empty_line_chart(self):
         chart_bg = self.chart_bg
         fig_line = px.line()
         fig_line.update_layout(plot_bgcolor=chart_bg, paper_bgcolor=chart_bg, margin=dict(l=85, r=60, t=30, b=40),
-                               height=320, font={"color": chart_bg})
+                               height=500, font={"color": chart_bg})
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
 
@@ -108,15 +103,18 @@ class Components:
                 else:
                     _checklist = dcc.Checklist(_options, _options, inline=True,
                                                id={'type': 'para-checklist', 'index': i},
-                                               labelStyle={},
-                                               inputStyle={'margin-left': '10px', 'margin-right': '3px'})
+                                               labelStyle={'font-size': '12px'},
+                                               #label_checked_style={"color": "red"},
+                                               inputStyle={'margin-left': '10px', 'margin-right': '3px','background-color':'red',
+                                                           'vertical-align':'middle','position':'relative',
+                                                           'bottom':'.15em'})
                 row = html.Div(
                     dbc.Row([
                         html.Div(para_name),
                         html.Div(style={'height': '5px'}),
                         html.Div(_checklist),
                         html.Div(style={'height': '5px'}),
-                    ]), style={'padding': '0px 20px', 'font-size': '15px'})
+                    ]), style={'padding': '0px 20px', 'font-size': '12px'})
 
                 checkbox_div.append(row)
 
@@ -201,18 +199,34 @@ class Components:
 
 
     def update_performance_matrix(self, start_date,end_date,df,para_dict):
-        per_col1 = []
+        per_col1 =[]
         per_col2 = []
         per_col_1_1 = []
         per_col_1_2 = []
-        per_col_2_1 = []
-        per_col_2_2 = []
+        per_col_2_1 = [html.Div(html.Img())]
+        per_col_2_2 = [html.Div('Selected',style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'})]
+        per_col_2_3 = [html.Div('BaH',style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'})]
 
-        keys = ['num_of_trade', 'net_profit', 'net_profit_to_mdd','total_commission',
-                'mdd_dollar', 'mdd_pct', 'return_on_capital', 'annualized_return', 'annualized_std', 'annualized_sr',
-                'return_to_bah', 'win_rate', 'cov',
-                'bah_mdd_dollar', 'bah_mdd_pct', 'bah_return', 'bah_annualized_return', 'bah_annualized_std',
-                'bah_annualized_sr']
+        keys = ['num_of_trade',
+                'net_profit',
+                'net_profit_to_mdd',
+                'total_commission',
+                'return_to_bah',
+                'win_rate',
+                'cov',
+                'return_on_capital',
+                'annualized_return',
+                'annualized_std',
+                'annualized_sr',
+                'mdd_dollar',
+                'mdd_pct',
+                'bah_return',
+                'bah_annualized_return',
+                'bah_annualized_std',
+                'bah_annualized_sr',
+                'bah_mdd_dollar',
+                'bah_mdd_pct',
+                ]
 
         try:
             df['net_profit'] = "{:,}".format(int(round(df['net_profit'], 0)))
@@ -241,87 +255,90 @@ class Components:
 
         per_col_1_1.append(html.Div('Number of Trade'))
         per_col_1_1.append(html.Div('Net Profit'))
-        per_col_1_1.append(html.Div('Net Profit to MDD'))
+        per_col_1_1.append(html.Div('Net Profit/MDD Ratio'))
         per_col_1_1.append(html.Div('Total Commission'))
-        per_col_1_1.append(html.Div(html.Img()))
-        per_col_1_1.append(html.Div('MDD Dollar'))
-        per_col_1_1.append(html.Div('MDD Percentage'))
-        per_col_1_1.append(html.Div('Return on Capital'))
-        per_col_1_1.append(html.Div('Annualized Return'))
-        per_col_1_1.append(html.Div('Annualized Std'))
-        per_col_1_1.append(html.Div('Annualized Sharp Ratio'))
+        per_col_1_1.append(html.Div('Return/BaH Ratio'))
+        per_col_1_1.append(html.Div('Win Rate'))
+        per_col_1_1.append(html.Div('COV'))
 
-        for i in range(4):
+        per_col_2_1.append(html.Div('Return on Capital'))
+        per_col_2_1.append(html.Div('Ann. Return'))
+        per_col_2_1.append(html.Div('Ann. Std'))
+        per_col_2_1.append(html.Div('Ann. Sharp Ratio'))
+        per_col_2_1.append(html.Div('MDD Dollar'))
+        per_col_2_1.append(html.Div('MDD Percentage'))
+
+        for i in range(7):
             per_col_1_2.append(html.Div(df[keys[i]], style={'text-align': 'center'}))
-        per_col_1_2.append(html.Div(html.Img()))
-        for i in range(4, 10):
-            per_col_1_2.append(html.Div(df[keys[i]], style={'text-align': 'center'}))
-
-        per_col_2_1.append(html.Div('Return to BaH Ratio'))
-        per_col_2_1.append(html.Div('Win Rate'))
-        per_col_2_1.append(html.Div('COV'))
-        per_col_2_1.append(html.Div(html.Img()))
-        per_col_2_1.append(html.Div(html.Img()))
-        per_col_2_1.append(html.Div('BaH MDD Dollar'))
-        per_col_2_1.append(html.Div('BaH MDD Percentage'))
-        per_col_2_1.append(html.Div('BaH Return'))
-        per_col_2_1.append(html.Div('BaH Annualized Return'))
-        per_col_2_1.append(html.Div('BaH Annualized Std'))
-        per_col_2_1.append(html.Div('BaH Annualized Sharp Ratio'))
-
-        for i in range(10, 13):
+        for i in range(7, 13):
             per_col_2_2.append(html.Div(str(df[keys[i]]), style={'text-align': 'center'}))
-        per_col_2_2.append(html.Div(html.Img()))
-        per_col_2_2.append(html.Div(html.Img()))
         for i in range(13, 19):
-            per_col_2_2.append(html.Div(str(df[keys[i]]), style={'text-align': 'center'}))
+            per_col_2_3.append(html.Div(str(df[keys[i]]), style={'text-align': 'center'}))
 
-        per_col1.append(dbc.Row([dbc.Col(html.Div(per_col_1_1), width=9),
-                                 dbc.Col(per_col_1_2, style={'padding': '0'}, width=3)]))
-        per_col2.append(dbc.Row([dbc.Col(html.Div(per_col_2_1), width=9),
-                                 dbc.Col(per_col_2_2, style={'padding': '0'}, width=3)]))
+        per_col1.append(dbc.Row([dbc.Col(html.Div(per_col_1_1), width=6),
+                                 dbc.Col(per_col_1_2, style={'padding': '0'}, width=6)]))
+        per_col2.append(dbc.Row([dbc.Col(html.Div(per_col_2_1), width=6),
+                                 dbc.Col(per_col_2_2, style={'padding': '0'}, width=3),
+                                 dbc.Col(per_col_2_3, style={'padding': '0'}, width=3)
+                                 ]))
 
         start_date_year = datetime.datetime.strptime(start_date, '%Y-%m-%d').year
         end_date_year = datetime.datetime.strptime(end_date, '%Y-%m-%d').year
         year_list = list(range(start_date_year, end_date_year + 1))
 
-        year_col1 = []
-        year_col2 = []
+        year_col1 = [dbc.Row([dbc.Col(style={'margin-left':'15px'}, width=3),
+                              dbc.Col('Year Count', style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'},width=4),
+                              dbc.Col('Win Rate', style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'},width=4)
+                              ], style={'font-size': '11px'})]
 
-        if len(year_list) < 11:
-            for i in range(len(year_list)):
-                year_col1.append(dbc.Row([dbc.Col(year_list[i], style={'padding-left': '20px'}, width=3),
-                                          dbc.Col(df[str(year_list[i])], style={'text-align': 'center'}
-                                                  , width=3)], style={'font-size': '11px'}))
 
+        for i in range(len(year_list)):
+            try:
+                # print(df[f'{year_list[i]}_win_rate'])
+                # # win_rate = df[f'{year_list[i]}_win_rate']
+                # print(df[f'{year_list[i]}_win_rate'].value())
+                # print(df[f'{year_list[i]}_win_rate'])
+                win_rate = "{:.0%}".format( int(df[f'{year_list[i]}_win_rate'])/100 )
+            except:
+                win_rate = '-----'
+
+            year_col1.append(dbc.Row([dbc.Col(year_list[i],style={'margin-left':'15px'} ,width=3),
+                                      dbc.Col(df[str(year_list[i])], style={'text-align': 'center'} , width=4),
+                                      dbc.Col(win_rate, style={'text-align': 'center'} , width=4)]))
+        # Selected Equity Curve
         title = []
         for key in para_dict:
-            title_div = []
-            title_div.append(html.Div(key, style={'margin-right': '5px', 'display': 'inline'}))
-            title_div.append(html.Div(':', style={'margin-right': '5px', 'display': 'inline'}))
-            title_div.append(html.Div(str(df[key]) + ' ', style={'margin-right': '10px', 'display': 'inline'}))
-            title.append(html.Span(title_div))
+            title.append(dbc.Row(
+                [dbc.Col(key,width=6),
+                dbc.Col(f'{df[key]}',style={ 'text-align': 'center'},width=6)]))
+
+
 
         matrix_div = html.Div([
+            html.Div(style={'height': '8px', }),
+
+            html.Div('Selected', style={'color': 'Cyan', 'font-size': '15px'}),
+            dbc.Row(html.Div(title), style={'font-size': '11px'}),
+            html.Div(style={'height': '15px', }),
+
+            html.Div('Performance', style={'color': 'Cyan', 'font-size': '15px'}),
+            html.Div(children=per_col1, style={'font-size': '11px'}),
+            html.Div(style={'height': '15px', }),
+
+            html.Div('Comparison', style={'color': 'Cyan', 'font-size': '15px'}),
+            html.Div(children=per_col2, style={'font-size': '11px','padding-right': '10px'}),
+            html.Div(style={'height': '15px', }),
+
+            html.Div('Performance by Year', style={'color': 'Cyan', 'font-size': '15px'}),
             html.Div(style={'height': '5px', }),
-            dbc.Row(html.Div(title), style={'padding-left': '10px', 'font-size': '14px'}),
-            html.Div(style={'height': '5px', }),
-            dbc.Row([
-                dbc.Col(html.Div(children=per_col1), style={'font-size': '11px'}, width=4),
-
-                dbc.Col(html.Div(children=per_col2), style={'font-size': '11px'}, width=4),
-
-                dbc.Col([html.Div('Year Signal Count', style={'font-size': '12px'}),
-                         html.Div(children=year_col1)], style={'padding-left': '30px'}, width=4),
-
-            ], style={'padding': '10px'})
-        ])
+            html.Div(children=year_col1, style={'font-size': '11px'})
+        ],style={'padding': '0px',})
 
         return matrix_div
 
 
     def selection_title(self, para_dict, values):
-        title = [html.Div('Selection',style={'color':'Cyan','font-size': '15px'})]
+        title = [html.Div('Selected',style={'color':'Cyan','font-size': '15px'})]
         for i, key in enumerate(para_dict):
             title_div = []
             title_div.append(html.Div(key, style={'margin-right': '5px', 'display': 'inline'}))
@@ -401,10 +418,11 @@ class Components:
     def generate_chart_1(self, graph_df, para_key_list, generate_filepath, filename, output_folder, start_date, end_date,
                    para_dict):
         fig_line = px.line()
+        fig_line.update_layout(title = {'text': 'Equity Curves'})
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
-        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=320,
-                               margin=dict(l=85, r=25, t=10, b=0),
+        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=500,
+                               margin=dict(l=85, r=25, t=60, b=0),
                                showlegend=False,
                                font={"color": "white", 'size': 10.5}, yaxis={'title': 'Equity'},
                                xaxis={'title': ''}
@@ -447,23 +465,10 @@ class Components:
 
     def prepare_df_chart(self, df):     # Chart Data for Chart 2
         initial_value = df.iloc[0].equity_value
-        # df_chart = pd.DataFrame()
-        # df_chart['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
-        # df_chart['close'] = df['close']
-        # df_chart['bah'] = df['close'] * (initial_value / df_chart.iloc[0].close)
-        # df_chart['equity_value'] = df['equity_value']
-        # df_chart['action'] = df['action']
-        # df_chart['volume'] = df['volume']
-        # df_chart['sma'] = df['sma']
 
         df_chart = df.copy()
         df_chart['date'] = pd.to_datetime(df_chart['date'], format='%Y-%m-%d')
-        #df_chart['close'] = df['close']
         df_chart['bah'] = df['close'] * (initial_value / df_chart.iloc[0].close)
-        # df_chart['equity_value'] = df['equity_value']
-        # df_chart['action'] = df['action']
-        # df_chart['volume'] = df['volume']
-        # df_chart['sma'] = df['sma']
 
         _open = []
         _stop_loss = []
@@ -506,7 +511,7 @@ class Components:
         return df_chart
 
 
-    def generate_chart_2(self,df_chart,line_colour, height):
+    def generate_chart_2(self,df_chart,line_colour, para_dict,para_values, settings):
         df_signal = df_chart.copy()
         df_signal = df_signal.dropna(subset=['action'])
         df_signal = df_signal.reset_index()
@@ -586,72 +591,89 @@ class Components:
             "Pct Change: %{customdata[5]}%",
         ])
 
+        self.selection_title(para_dict, para_values)
 
-        # fig_line = px.line(df_chart, x='date', y="equity_value",
-        #                    title="Automatic Labels Based on Data Frame Column Names")
-        fig_line = px.line(df_chart, x='date', y="equity_value")
-        fig_line.update_traces(line_color='rgba(0, 0, 0, 0)')
+        title = ''
+        for i, key in enumerate(para_dict):
+            title = title + f'{key}:{para_values[i]} '
+
+        # Count number of subchart
+        subchart_count = 0
+        try:
+            fig = settings['subchart_1']
+            subchart_count += 1
+        except Exception as e: pass
+        try:
+            fig = settings['subchart_2']
+            subchart_count += 1
+        except Exception as e: pass
+
+        if subchart_count == 0: row_height = [1]
+        if subchart_count == 1: row_height = [0.85,0.15]
+        if subchart_count == 2: row_height = [0.7,0.15,0.15]
+
+        fig_line = make_subplots(rows=subchart_count+1, cols=1,
+                                 row_heights=row_height,shared_xaxes=True)
+
+        fig_line.update_layout(title = {'text': title , 'font': {'size': 10 }  })
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
                                       x=df_chart['date'], y=df_chart['equity_value'],
-                                      line=dict(color=line_colour, width=1), name='Strategy Equity'), )
-        # fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
-        #                               x=df_chart['date'], y=df_chart['bah'],
-        #                               line=dict(color='#00FFFF', width=1), name='BnH Equity'), )
+                                      line=dict(color=line_colour, width=1), name='Strategy Equity'), row=1, col=1)
         fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
                                       x=df_chart['date'], y=df_chart['bah'],
-                                      line=dict(color='white', width=1), name='BnH Equity'), )
-        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=height,
-                               margin=dict(l=85, r=25, t=25, b=0),
+                                      line=dict(color='Grey', width=1), name='BnH Equity'),row=1, col=1 )
+        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=500,
+                               margin=dict(l=85, r=25, t=35, b=20),
                                font={"color": "white", 'size': 9}, yaxis={'title': 'Equity'},
                                xaxis={'title': ''}
                                )
         fig_line.add_trace(go.Scatter(mode='markers', customdata=df_signal_final, hovertemplate=hover_template,
                                       x=df_chart['date'], y=df_chart['open'], visible='legendonly',
-                                      marker=dict(color='rgba(0, 0, 0, 0)', size=8,
-                                                  line=dict(color='yellow', width=1.5)), name='open'), )
+                                      marker=dict(color='rgba(0, 0, 0, 0)', size=9,
+                                                  line=dict(color='yellow', width=2.5)), name='open'), row=1, col=1)
         fig_line.add_trace(go.Scatter(mode='markers', customdata=df_signal_final, hovertemplate=hover_template,
                                       x=df_chart['date'], y=df_chart['close_logic'], visible='legendonly',
-                                      marker=dict(color='rgba(0, 0, 0, 0)', size=8,
-                                                  line=dict(color='green', width=1.5)), name='close_logic'), )
+                                      marker=dict(color='rgba(0, 0, 0, 0)', size=9,
+                                                  line=dict(color='green', width=2.5)), name='close_logic'), row=1, col=1)
         fig_line.add_trace(go.Scatter(mode='markers', customdata=df_signal_final, hovertemplate=hover_template,
                                       x=df_chart['date'], y=df_chart['profit_target'], visible='legendonly',
-                                      marker=dict(color='rgba(0, 0, 0, 0)', size=8,
-                                                  line=dict(color='red', width=1.5)), name='profit_target'), )
+                                      marker=dict(color='rgba(0, 0, 0, 0)', size=9,
+                                                  line=dict(color='red', width=2.5)), name='profit_target'), row=1, col=1)
         fig_line.add_trace(go.Scatter(mode='markers', customdata=df_signal_final, hovertemplate=hover_template,
                                       x=df_chart['date'], y=df_chart['stop_loss'], visible='legendonly',
-                                      marker=dict(color='rgba(0, 0, 0, 0)', size=8,
-                                                  line=dict(color='blue', width=1.5)), name='stop_loss'), )
+                                      marker=dict(color='rgba(0, 0, 0, 0)', size=9,
+                                                  line=dict(color='Cyan', width=2.5)), name='stop_loss'), row=1, col=1)
+
+
+        subchart_count = 2
+        try:
+            fig = self.generate_subchart(df_chart, settings['subchart_1'][0], settings['subchart_1'][1], 'yellow')
+            fig_line.add_trace(fig, row=subchart_count, col=1)
+            subchart_count += 1
+        except Exception as e:
+            # print(e)
+            pass
+        try:
+            fig = self.generate_subchart(df_chart, settings['subchart_2'][0], settings['subchart_2'][1], '#FF01FE')
+            fig_line.add_trace(fig, row=subchart_count, col=1)
+        except Exception as e:
+            # print(e)
+            pass
+
 
-        fig_line.update_layout(xaxis_range=[df_chart.iloc[0].date, df_chart.iloc[-1].date])
 
         return fig_line
 
 
-
     def generate_subchart(self,df_chart, element, line_type, line_color):
         if line_type == 'bar':
-            fig = go.Figure(
-                data=[
-                    go.Bar(hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
-                           marker_color=line_color, marker_line_color=line_color, name=element),
-                ])
+            fig = go.Bar(hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
+                           marker_color=line_color, marker_line_color=line_color, name=element)
         else:
-            fig = go.Figure(data=[
-                go.Scatter(mode='lines', hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
-                           line=dict(color=line_color, width=1.5), name=element), ] )
-
-        fig.update_layout(width=823)
-        fig.update_layout(plot_bgcolor='#1f2c56', paper_bgcolor='#1f2c56', height=60,
-                          margin=dict(l=85, r=50, t=25, b=20),
-                          font={"color": "white",'size': 9}, yaxis={'fixedrange': True}, xaxis={'fixedrange': True},
-                          bargap=0, )
-        fig.update_layout(legend=dict(orientation="h", bgcolor='rgba(0, 0, 0, 0)',
-                                          yanchor="bottom", y=0.99, xanchor="right", x=0.135))
-        fig.update_xaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor='#1f2c56', )
-        fig.update_yaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor='#626567', mirror=True)
-
+            fig = go.Scatter(mode='lines', hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
+                           line=dict(color=line_color, width=1.5), name=element)
         return fig
 
 
@@ -665,14 +687,13 @@ class Components:
         df_his[col_pct] = df_his[col_pct].shift(-1 * period)
         df_his[col_pct] = df_his[col_pct] * 100
         df_his[col_pct] = df_his[col_pct].map(lambda x: round(x, 2))
+        df_his[col_rise] = (df_his['high'].rolling(period).max().shift(-1 * (period)) / df_his['close']) - 1
+        df_his[col_fall] = (df_his['low'].rolling(period).min().shift(-1 * (period)) / df_his['close']) - 1
         if mode == 'backtest':
             df_his = df_his[df_his['action'] == 'open']
         else:
             df_his = df_his[df_his['logic'] == 'trade_logic']
 
-        df_his[col_rise] = (df_his['high'].rolling(period).max().shift(-1 * (period)) / df_his['close']) - 1
-        df_his[col_fall] = (df_his['low'].rolling(period).min().shift(-1 * (period)) / df_his['close']) - 1
-
         df_his[col_rise] = df_his[col_rise] * 100
         df_his[col_fall] = df_his[col_fall] * 100
 
@@ -719,11 +740,11 @@ class Components:
         df_his[col_pct] = df_his[col_pct].shift(-1 * period)
         df_his[col_pct] = df_his[col_pct] * 100
         df_his[col_pct] = df_his[col_pct].map(lambda x: round(x, 2))
-        df_his = df_his[df_his['logic'] == 'trade_logic']
-
         df_his[col_rise] = (df_his['high'].rolling(period).max().shift(-1 * (period)) / df_his['close']) - 1
         df_his[col_fall] = (df_his['low'].rolling(period).min().shift(-1 * (period)) / df_his['close']) - 1
 
+        df_his = df_his[df_his['logic'] == 'trade_logic']
+
         df_his[col_rise] = df_his[col_rise] * 100
         df_his[col_fall] = df_his[col_fall] * 100
 
