@@ -1,12 +1,4 @@
-import pandas as pd
-import datetime
-import math
-import numpy as np
-
 from dash import Dash, dcc, html, Input, Output, State, ALL
-import dash_bootstrap_components as dbc
-import plotly.express as px
-import plotly.graph_objs as go
 
 from .components import *
 
@@ -53,9 +45,7 @@ class Plot:
         app = Dash(__name__, external_stylesheets=[dbc.themes.SUPERHERO], suppress_callback_exceptions=True)
 
         app.layout = html.Div([
-
             html.Div(style={'height': '10px', }),
-
             html.Div(
                 dbc.Row([
                     # Left Column
@@ -64,66 +54,58 @@ class Plot:
                         sort_method_dropdown,
                         html.Div(style={'height': '10px', }),
                         html.Div(id='checklist-container',children=checkbox_div),
-                        html.Div('-----------------------------------------------',style={'margin-left': '15px'}),
-                        html.Div('Filters for:', style={'margin-left': '14px'}),
+                        html.Div('--------------------------------------',style={'margin-left': '15px'}),
+                        html.Div('Filters for:', style={'margin-left': '12px'}),
                         html.Div(style={'height': '10px', }),
                         html.Div(id='filter', children=filter_div,style={'padding': '0px 20px',
                                                                          'padding-right': '30px',
                                                                          'font-size': '12px'}),
-
                         dbc.Row([
                             dbc.Col(id='filter_dropdown_div',children=filter_dropdown,width=8),
                             dbc.Col(id='filter_input_div',children=filter_input,width=3),
                         ]),
-
                         html.Div(style={'height': '10px', }),
-
-                        html.Div(id='add_button',children='Add Filter',style=add_button_style),
+                        html.Div(id='add_button',children=html.Div([html.Div(style={'height': '5px'}),'Add Filter']),
+                                 style=add_button_style),
 
                     ],style={'padding':'0px','border-radius':'5px','height': '704px',
                              'background-color':'rgba(0, 0, 0, 0)'})
-                        ,style={'padding':'0',}, width=3),
+                        ,style={'padding':'0',}, width=2),
+
+                    # Middle Column
+                    dbc.Col(html.Div([
+                        html.Div(id='performance_matrix', children=performance_matrix ),
+
+
+                    ], style={'padding': '5px',})
+                        , style={'padding': '0', }, width=2),
 
 
                     # Right Column
                     dbc.Col(html.Div([
-                        html.Div(id='performance_matrix',children=performance_matrix,
-                                 style={'padding': '5px', 'border-radius': '5px', 'background-color': chart_bg}),
-
                         html.Div(style={'height': '5px', }),
+                        html.Div([html.Div(html.Img(),style={'height':'10px'}),
 
-                        html.Div([html.Div(html.Img(),style={'height':'5px'}),
                                   dbc.Row([
                                       dbc.Col(html.Div(id='chart1_button', children='',
                                                        style={'text-align': 'left', 'cursor': 'pointer',
-                                                              'font-size': '12px'}), width=4),
+                                                              'font-size': '14px'}), width=4),
                                       dbc.Col(html.Div(html.Img()), width=4),
                                       dbc.Col(html.Div(id='chart2_button', children=''), width=4),
                                   ], style={'margin': '0px 5px'}),
                                   html.Div(id='chart_area',
                                            children=dcc.Graph(id='line_chart', figure=empty_line_chart)),
+                                  html.Div(style={'height': '10px', }),
 
-                                  html.Div(id='sub_chart1_area',\
-                                           children=dcc.Graph(id='sub_chart1', figure=empty_line_chart,\
-                                                              config={'displayModeBar': False}),
-                                           style={'display': 'none'}),
-                                  html.Div(id='sub_chart2_area', \
-                                           children=dcc.Graph(id='sub_chart2', figure=empty_line_chart,\
-                                                              config={'displayModeBar': False}),
-                                           style={'display': 'none'}),
                                  ],style={'padding':'5px','border-radius':'5px','background-color':chart_bg}),
-
                         html.Div(style={'height': '5px', }),
-
                         html.Div(id='hist_area', children=html.Div(),
                                  style={'display': 'none'}),
-
-                    ]), style={'padding':'0','padding-left':'5px'}, width=9),
+                    ]), style={'padding':'0'}, width=8),
                 ])
             ),
 
-        ], style={'width':'1200px','margin':'auto','padding':'0px','color':'white'})
-
+        ], style={'width':'1500px','margin':'auto','padding':'0px 10px','color':'white'})
 
 
         @app.callback(
@@ -135,10 +117,6 @@ class Plot:
             Output('filter_input', 'value'),
             Output('chart1_button', 'children'),
             Output('chart2_button', 'children'),
-            Output('sub_chart1_area', 'style'),
-            Output('sub_chart1', 'figure'),
-            Output('sub_chart2_area', 'style'),
-            Output('sub_chart2', 'figure'),
             Output('hist_area', 'children'),
             Output('hist_area', 'style'),
             Input('sort_method', 'value'),
@@ -146,7 +124,6 @@ class Plot:
             State('filter_dropdown_div', 'children'),
             State('filter_input_div', 'children'),
             State('line_chart', 'figure'),
-            Input('line_chart', 'relayoutData'),
             State('filter', 'children'),
             Input('add_button', 'n_clicks'),
             Input('chart1_button', 'n_clicks'),
@@ -154,83 +131,33 @@ class Plot:
             State('add_button', 'style'),
             State('filter_name', 'value'),
             State('filter_input', 'value'),
-            State('sub_chart1_area', 'style'),
-            State('sub_chart1', 'figure'),
-            State('sub_chart2_area', 'style'),
-            State('sub_chart2', 'figure'),
             State('hist_area', 'children'),
             State('hist_area', 'style'),
             [Input('button_' + str(i), 'n_clicks') for i in range(10)],
         )
         def display_output(sort_method,para_checklist,filter_dropdown_div,filter_input_div,fig_line,\
-                           relayoutData, filter_div,add_button_clicks, \
+                           filter_div,add_button_clicks, \
                            chart1_button_clicks,chart2_button_clicks,\
                            _add_button_style,filter_name,filter_input_value,\
-                           sub_chart1_area,sub_chart1,\
-                           sub_chart2_area,sub_chart2,hist_area,hist_style, *vals):
+                           hist_area,hist_style, *vals):
 
 
             chart1_button_text = ''
             chart2_button_text = ''
 
-
-            if not relayoutData == self.relayoutData:
-                self.relayoutData = relayoutData
-                if self.chart_type == 1:
-                    chart2_button_text = 'Strategy Analysis >'
-                    return fig_line, filter_div, filter_dropdown_div, filter_input_div, _add_button_style, \
-                           None, chart1_button_text, chart2_button_text, \
-                           sub_chart1_area, sub_chart1, sub_chart2_area, sub_chart2, hist_area, hist_style
-                else:
-                    # Only trigger when chart 2, change the subchart only
-                    para_key_list = list(para_dict)
-                    para_values = []
-                    for key in para_key_list:
-                        para_values.append(self.graph_df.iloc[self.line_selected][key])
-                    save_path = generate_filepath(filename, output_folder, start_date, end_date, para_dict,
-                                                  para_values)
-                    df = pd.read_csv(save_path)
-                    df_chart = components.prepare_df_chart(df)
-
-                    chart1_button_text = '< Back'
-
-                    sub_chart1 = components.generate_subchart(df_chart, settings['subchart_1'][0],
-                                                              settings['subchart_1'][1], 'yellow')
-                    sub_chart2 = components.generate_subchart(df_chart, settings['subchart_2'][0],
-                                                              settings['subchart_2'][1], '#FF01FE')
-
-                    try:
-                        sub_chart1 = go.Figure(sub_chart1).update_layout(
-                            xaxis_range=[relayoutData['xaxis.range[0]'], relayoutData['xaxis.range[1]']])
-                        sub_chart2 = go.Figure(sub_chart2).update_layout(
-                            xaxis_range=[relayoutData['xaxis.range[0]'], relayoutData['xaxis.range[1]']])
-                    except:
-                        pass
-
-
-                    return fig_line, filter_div, filter_dropdown_div, filter_input_div, _add_button_style, \
-                           None, chart1_button_text, chart2_button_text, \
-                           sub_chart1_area, sub_chart1, sub_chart2_area, sub_chart2, hist_area, hist_style
-
-
-
             if chart1_button_clicks:
                 if chart1_button_clicks > self.chart1_button_clicks:
                     self.chart1_button_clicks = chart1_button_clicks
                     self. chart_type = 1
-                    sub_chart1_area = {'display': 'none'}
-                    sub_chart2_area = {'display': 'none'}
                     hist_style = {'display': 'none'}
 
-
             if chart2_button_clicks:
                 if chart2_button_clicks > self.chart2_button_clicks:
                     self.chart2_button_clicks = chart2_button_clicks
                     if self.chart_type == 2:
                         chart1_button_text = '< Back'
                         return fig_line, filter_div, filter_dropdown_div, filter_input_div, _add_button_style, \
-                               None, chart1_button_text, chart2_button_text, \
-                               sub_chart1_area, sub_chart1, sub_chart2_area, sub_chart2, hist_area, hist_style
+                               None, chart1_button_text, chart2_button_text, hist_area, hist_style
                     else:
                         if self.line_selected > -1:
                             para_key_list = list(para_dict)
@@ -242,47 +169,26 @@ class Plot:
                             line_colour = self.graph_df.iloc[self.line_selected].line_colour
                             df = pd.read_csv(save_path)
                             df_chart = components.prepare_df_chart(df)
-                            # fig_line = components.generate_chart_2(df_chart, line_colour)
 
                             self.chart_type = 2
                             chart1_button_text = '< Back'
 
-                            # Generate subscharts first
-                            subchart_count = 0
-                            try:
-                                sub_chart1 = components.generate_subchart(df_chart, settings['subchart_1'][0],
-                                                                          settings['subchart_1'][1], 'yellow')
-                                sub_chart1_area = {}
-                                subchart_count += 1
-                            except:
-                                pass
-                            try:
-                                sub_chart2 = components.generate_subchart(df_chart, settings['subchart_2'][0],
-                                                                          settings['subchart_2'][1], '#FF01FE')
-                                sub_chart2_area = {}
-                                subchart_count += 1
-                            except:
-                                pass
-
-                            # Generate Chart 2 after knowing subchart count
-                            # fig_line = components.generate_chart_2(df_chart, line_colour, 340 - subchart_count*60 - 20)
                             fig_line = components.generate_chart_2(df_chart, line_colour,
-                                                                   440 - subchart_count * 60 - 20)
-
+                                                                   para_dict,para_values, settings)
 
 
                             # Histograms
                             period = settings['histogram_period']
                             # First column of the 5 charts
                             title_list = [dbc.Col(width=1)]
-                            pct_list = [dbc.Col(html.Div('pct_change', style={'font-size': '12px', 'margin-top': '60px',
-                                                                              'margin-left': '40px',
+                            pct_list = [dbc.Col(html.Div('pct_change', style={'font-size': '12px', 'margin-top': '55px',
+                                                                              'margin-left': '45px',
                                                                               'transform': 'rotate(-90deg)'}), width=1)]
                             rise_list = [dbc.Col(html.Div('max_rise', style={'font-size': '12px', 'margin-top': '55px',
-                                                                              'margin-left': '40px',
+                                                                              'margin-left': '45px',
                                                                               'transform': 'rotate(-90deg)'}), width=1)]
                             fall_list = [dbc.Col(html.Div('max_fall', style={'font-size': '12px', 'margin-top': '55px',
-                                                                              'margin-left': '40px',
+                                                                              'margin-left': '45px',
                                                                               'transform': 'rotate(-90deg)'}), width=1)]
 
 
@@ -309,8 +215,7 @@ class Plot:
                             hist_style = {'padding': '5px', 'border-radius': '5px', 'background-color': chart_bg}
 
                             return fig_line, filter_div, filter_dropdown_div, filter_input_div, _add_button_style,\
-                                   None, chart1_button_text, chart2_button_text, \
-                                   sub_chart1_area, sub_chart1, sub_chart2_area, sub_chart2, hist_area, hist_style
+                                   None, chart1_button_text, chart2_button_text, hist_area, hist_style
 
 
                         else:
@@ -326,16 +231,13 @@ class Plot:
                    self.chart2_button_clicks = 0
                    self.line_selected = -1
                    self.chart_type = 1
-                   sub_chart1_area = {'display': 'none'}
-                   sub_chart2_area = {'display': 'none'}
                    hist_area = []
                    hist_style = {'display': 'none'}
                    self.init = True
                    filter_dropdown_div = filter_dropdown
                    filter_input_div = filter_input
                    return fig_line, filter_div, filter_dropdown_div,filter_input_div,_add_button_style, \
-                          None, chart1_button_text, chart2_button_text, \
-                          sub_chart1_area, sub_chart1, sub_chart2_area, sub_chart2, hist_area, hist_style
+                          None, chart1_button_text, chart2_button_text, hist_area, hist_style
 
 
             ## Add Button Pressed
@@ -382,9 +284,11 @@ class Plot:
                 # Filter according to the filer list
                 if len(self.filter_list) > 0:
                     for element in self.filter_list:
-                        print(element)
+                        # print(element)
                         if element[0] == 'exclude':
-                            current_df = current_df.loc[current_df['code'] != str(element[2])]
+                            try: code = int(element[2])
+                            except: code = element[2]
+                            current_df = current_df.loc[current_df['code'] != code]
                         elif element[1] == '<':
                             current_df = current_df.loc[current_df[element[0]] < float(element[2])]
                         else:
@@ -416,21 +320,17 @@ class Plot:
                 graph_df = components.sort_method_df(sort_method, df_checked)
                 self.graph_df = graph_df
 
-
                 fig_line = components.generate_chart_1(graph_df, para_key_list, generate_filepath, filename,
                                                       output_folder, start_date, end_date, para_dict)
 
                 # Disable Chart 2
                 chart2_button_text = 'Strategy Analysis >'
                 self.chart_type = 1
-                sub_chart1_area = {'display': 'none'}
-                sub_chart2_area = {'display': 'none'}
                 hist_style = {'display': 'none'}
 
 
             return fig_line, filter_div, filter_dropdown_div,filter_input_div,_add_button_style, \
-                   None, chart1_button_text, chart2_button_text, \
-                   sub_chart1_area, sub_chart1, sub_chart2_area, sub_chart2, hist_area, hist_style
+                   None, chart1_button_text, chart2_button_text, hist_area, hist_style
 
 
 
@@ -441,14 +341,14 @@ class Plot:
             State(component_id='performance_matrix', component_property='children'),
         )
         def update_matrix(clickData,performance_matrix):
-            button_style = {'text-align': 'right','color':'grey','font-size':'12px'}
+            button_style = {'text-align': 'right','color':'grey','font-size':'14px'}
             if clickData:
                 if self.chart_type == 1:
                     i = clickData['points'][0]['curveNumber'] - 1
                     performance_matrix = components.update_performance_matrix(start_date, end_date,
                                                                               self.graph_df.iloc[i].copy(), para_dict)
                     self.line_selected = i
-                    button_style = {'text-align': 'right','cursor': 'pointer','font-size':'12px'}
+                    button_style = {'text-align': 'right','cursor': 'pointer','font-size':'14px'}
             return performance_matrix, button_style
 
 
