@@ -14,7 +14,7 @@ class Signals:
     # Settings
     chart_bg = '#1f2c56'
 
-    def __new__(self, filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings):
+    def __new__(self, filename, output_folder, start_date, end_date, para_dict, generate_filepath, settings):
 
         chart_bg = self.chart_bg
         components = Components()
@@ -22,6 +22,7 @@ class Signals:
         radioitems_div = components.generate_radioitems(para_dict)
         period = settings['histogram_period']
         stat_ = ['---', '---', '---', '---', '---']
+        para_values =  ['-----' for key in para_dict]
 
         app = Dash(__name__, external_stylesheets=[dbc.themes.SUPERHERO], suppress_callback_exceptions=True)
 
@@ -34,12 +35,13 @@ class Signals:
 
                     # Left Column
                     dbc.Col(html.Div([
-                        html.Div(style={'height': '10px', }),
+
+                        html.Div(style={'height': '20px', }),
 
                         html.Div(id='radioitems_container',children=radioitems_div),
 
                     ],style={'padding':'0px','border-radius':'5px',
-                             'padding-left':'50px','height': '704px',
+                             'padding-left':'50px','padding-right':'15px','height': '704px',
                              'background-color':'rgba(0, 0, 0, 0)'})
                         ,style={'padding':'0',}, width=3),
 
@@ -49,11 +51,18 @@ class Signals:
 
                         html.Div(style={'height': '5px', }),
 
-                        html.Div(id='stat_area',
-                                 children=components.update_stat_div(period, stat_, stat_, stat_),
-                                 style={'padding': '5px 25px', 'border-radius': '5px', 'font-size': '13px',
-                                        'padding-left': '40px', 'padding-right': '80px', 'text-align': 'center',
-                                        'background-color': chart_bg}),
+                        html.Div(children=html.Div([
+                                 html.Div(style={'height': '10px', }),
+                                 html.Div(id='title_area',
+                                     children=components.selection_title(para_dict, para_values),
+                                          style={'padding-left': '10px', 'font-size': '14px'}),
+                                 html.Div(id='stat_area',
+                                     children=components.update_stat_div(period, stat_, stat_, stat_),
+                                     style={'padding-left': '40px', 'padding-right': '80px',
+                                                 'text-align': 'center'})]),
+
+                             style={'padding': '5px 25px', 'border-radius': '5px', 'font-size': '13px',
+                                    'background-color': chart_bg}),
 
                         html.Div(style={'height': '5px', }),
 
@@ -80,18 +89,24 @@ class Signals:
         ], style={'width':'1200px','margin':'auto','padding':'0px','color':'white'})
 
         @app.callback(
+            Output('title_area', 'children'),
             Output('stat_area', 'children'),
             Output('line_chart', 'figure'),
             Output('hist_area', 'children'),
+            State('title_area', 'children'),
             State('stat_area', 'children'),
             State('line_chart', 'figure'),
             State('hist_area', 'children'),
             Input({'type': 'para_radioitems', 'index': ALL}, 'value'),
         )
-        def display_output(stat_area, line_chart, hist_area, para_radioitems):
+        def display_output(title_area, stat_area, line_chart, hist_area, para_radioitems):
 
+            # Not complete selection
             if None in para_radioitems:
-                return stat_area, line_chart, hist_area
+                return title_area, stat_area, line_chart, hist_area
+
+            # for i, key in enumerate(para_dict):
+            #     print(key, para_radioitems[i])
 
             save_path = generate_filepath(
                 py_filename=filename,
@@ -178,16 +193,11 @@ class Signals:
                          rise_list, fall_list,
                          html.Div(style={'height': '15px', })]
 
-            hist_style = {'padding': '5px', 'border-radius': '5px',
-                          'padding-left': '50px','padding-right': '40px',
-                          'background-color': chart_bg}
-
+            title_area = components.selection_title(para_dict, para_radioitems)
 
             stat_area = components.update_stat_div(period, pct_mean, rise_mean, fall_mean)
 
-
-
-            return stat_area, line_chart, hist_area
+            return title_area, stat_area, line_chart, hist_area
 
 
         return app
\ No newline at end of file
